pygeodesy.namedTuples.Circle4Tuple

Package pygeodesy :: Module namedTuples :: Class Circle4Tuple |
[frames] | no frames]

# Class Circle4Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Circle4Tuple

4-Tuple `(radius, height, lat, beta)` with the `radius` and `height` of a parallel circle of latitude at (geodetic) latitude `lat` and parametric (or reduced) auxiliary latitude `beta` on a biaxial ellipsoid.

The `height` is the (signed) distance along the z-axis between the parallel and the equator. At near-polar `lat`s, the `radius` is `0`, the `height` is the ellipsoid's polar radius (signed) and `beta` equals `lat`. The latter are in `degrees90`, always.

See Also: Class Ellipse5Tuple.

Instance Methods
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
| abc3 Get the non-negative semi-axes as 3-tuple `(a, b, c)`.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Property Details

### abc3 Get the non-negative semi-axes as 3-tuple `(a, b, c)`. Get method: abc3(self) - Get the non-negative semi-axes as 3-tuple `(a, b, c)`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.